@@ -13,7 +13,7 @@ use Carp qw/confess/;
 use parent 'Exporter';    # inherit all of Exporter's methods
 our @EXPORT_OK = qw(anon_requires);
 
-our $VERSION = "0.0.6";
+our $VERSION = "0.0.7";
 
 {
     my %compilations_of_types;
@@ -39,6 +39,54 @@ our $VERSION = "0.0.6";
     }
 }
 
+sub UNIVERSAL::ScalarContext : ATTR(CODE) {
+    no warnings 'redefine';
+    no strict 'refs';
+    my (
+        $package, $symbol, $referent, $attr,
+        $data,    $phase,  $filename, $linenum
+    ) = @_;
+    if ( $symbol eq 'ANON' ) {
+        local $Carp::Internal{'Attribute::Validate'} = 1;
+        confess "Unable to add validation to anon subroutine";
+    }
+    my $orig_sub = *{$symbol}{CODE};
+    *{$symbol} = sub {
+        local $Carp::Internal{'Attribute::Validate'} = 1;
+        if ( !defined wantarray  ) {
+            confess 'The return of this sub must be used in scalar context';
+        }
+        if (wantarray) {
+            confess 'The return of this sub must be used in scalar context';
+        }
+        goto &$orig_sub;
+    }
+}
+
+sub UNIVERSAL::NoScalarContext : ATTR(CODE) {
+    no warnings 'redefine';
+    no strict 'refs';
+    my (
+        $package, $symbol, $referent, $attr,
+        $data,    $phase,  $filename, $linenum
+    ) = @_;
+    if ( $symbol eq 'ANON' ) {
+        local $Carp::Internal{'Attribute::Validate'} = 1;
+        confess "Unable to add validation to anon subroutine";
+    }
+    my $orig_sub = *{$symbol}{CODE};
+    *{$symbol} = sub {
+        local $Carp::Internal{'Attribute::Validate'} = 1;
+        if ( !defined wantarray  ) {
+            goto &$orig_sub;
+        }
+        if (wantarray) {
+            goto &$orig_sub;
+        }
+        confess 'The return of this sub must never be used in scalar context';
+    }
+}
+
 sub UNIVERSAL::ListContext : ATTR(CODE) {
     no warnings 'redefine';
     no strict 'refs';
@@ -236,7 +284,7 @@ Enforces the caller to do something with the return of a sub to avoid programmer
     only_use_in_list_context(); # Dies
     my @list = only_use_in_list_context(); # Works
 
-Enforces the caller to use the function in List Context to prevent errors and misunderstandings.
+Enforces the caller to use the subroutine in List Context to prevent errors and misunderstandings.
 
 =head2 NoListContext
 
@@ -247,7 +295,29 @@ Enforces the caller to use the function in List Context to prevent errors and mi
     never_use_in_list_context(); # Works
     my @list = never_use_in_list_context(); # Dies
 
-Enforces the caller to never use the function in List Context to prevent errors and misunderstandings.
+Enforces the caller to never use the subroutine in List Context to prevent errors and misunderstandings.
+
+=head2 ScalarContext
+
+    sub only_use_in_scalar_context: ScalarContext {
+        return 'hey';
+    }
+    my @scalar = only_use_in_scalar_context(); # Dies
+    only_use_in_scalar_context(); # Dies
+    my $scalar = only_use_in_scalar_context(); # Works
+
+Enforces the caller to use the subroutine in Scalar Context to prevent errors and misunderstandings.
+
+=head2 NoScalarContext
+
+    sub never_scalar_context: NoScalarContext {
+        return @array;
+    }
+    my @list = never_scalar_context(); # Works
+    never_scalar_context(); # Works
+    my $scalar = never_scalar_context(); # Dies
+
+Enforces the caller to never use the subroutine in Scalar Context to prevent errors and misunderstandings.
 
 =head1 EXPORTABLE SUBROUTINES
 
